==> mlonmcu-0.3.0.dev0.tar.gz: mlonmcu-0.3.0.dev0/tests/unit-tests/setup/test_setup_utils.py <==
#
# Copyright (c) 2022 TUM Department of Electrical and Computer Engineering.
#
# This file is part of MLonMCU.
# See https://github.com/tum-ei-eda/mlonmcu.git for further info.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import pytest
from io import StringIO

from mlonmcu.setup.utils import (
    makeFlags,
    makeDirName,
    mkdirs,
    clone,
    apply,
    make,
    cmake,
    download,
    extract,
    remove,
    move,
    copy,
    is_populated,
    download_and_extract,
)


def test_setup_utils_makeFlags():
    pass


def test_setup_makeDirName():
    pass


# def test_setup_exec():
#     pass
#
#
# def test_setup_exec_getout():
#     pass
#
#
# def test_setup_python():
#     pass


def test_setup_mkdirs():
    pass


def test_setup_clone():
    pass


def test_setup_apply():
    pass


def test_setup_make():
    pass


def test_setup_cmake():
    pass


def test_setup_download():
    pass


def test_setup_extract():
    pass


def test_setup_remove():
    pass


def test_setup_move():
    pass


def test_setup_copy():
    pass


def test_setup_is_populated():
    pass


def test_setup_download_and_extract():
    pass


# def makeFlags(*args):
# def makeDirName(base: str, *args, flags: list = None) -> str:
# def exec(*args, **kwargs):
# def exec_getout(*args, live: bool = False, print_output: bool = True, handle_exit=None, prefix="", **kwargs) -> str:
# def python(*args, **kwargs):
# def mkdirs(path: Union[str, bytes, os.PathLike]):
# def clone( url: str, dest: Union[str, bytes, os.PathLike], branch: str = "", recursive: bool = False, refresh: bool = False,):
# def apply( repo_dir: Path, patch_file: Path,):
# def make(*args, threads=multiprocessing.cpu_count(), use_ninja=False, cwd=None, verbose=False, **kwargs):
# def cmake(src, *args, debug=False, use_ninja=False, cwd=None, **kwargs):
# def download(url, dest, progress=False):
# def extract(archive, dest, progress=False):
# def remove(path):
# def move(src, dest):
# def copy(src, dest):
# def is_populated(path):
# def download_and_extract(url, archive, dest, progress=False):

==> mlonmcu-0.5.dev0.tar.gz: mlonmcu-0.5.dev0/tests/unit-tests/setup/test_setup_utils.py <==
#
# Copyright (c) 2022 TUM Department of Electrical and Computer Engineering.
#
# This file is part of MLonMCU.
# See https://github.com/tum-ei-eda/mlonmcu.git for further info.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# from mlonmcu.setup.utils import (
#     makeFlags,
#     makeDirName,
#     mkdirs,
#     clone,
#     apply,
#     make,
#     cmake,
#     download,
#     extract,
#     remove,
#     move,
#     copy,
#     is_populated,
#     download_and_extract,
# )


def test_setup_utils_makeFlags():
    pass


def test_setup_makeDirName():
    pass


# def test_setup_exec():
#     pass
#
#
# def test_setup_exec_getout():
#     pass
#
#
# def test_setup_python():
#     pass


def test_setup_mkdirs():
    pass


def test_setup_clone():
    pass


def test_setup_apply():
    pass


def test_setup_make():
    pass


def test_setup_cmake():
    pass


def test_setup_download():
    pass


def test_setup_extract():
    pass


def test_setup_remove():
    pass


def test_setup_move():
    pass


def test_setup_copy():
    pass


def test_setup_is_populated():
    pass


def test_setup_download_and_extract():
    pass


# def makeFlags(*args):
# def makeDirName(base: str, *args, flags: list = None) -> str:
# def exec(*args, **kwargs):
# def exec_getout(*args, live: bool = False, print_output: bool = True, handle_exit=None, prefix="", **kwargs) -> str:
# def python(*args, **kwargs):
# def mkdirs(path: Union[str, bytes, os.PathLike]):
# def clone( url: str, dest: Union[str, bytes, os.PathLike], branch: str = "",
#     recursive: bool = False, refresh: bool = False,):
# def apply( repo_dir: Path, patch_file: Path,):
# def make(*args, threads=multiprocessing.cpu_count(), use_ninja=False, cwd=None, verbose=False, **kwargs):
# def cmake(src, *args, debug=False, use_ninja=False, cwd=None, **kwargs):
# def download(url, dest, progress=False):
# def extract(archive, dest, progress=False):
# def remove(path):
# def move(src, dest):
# def copy(src, dest):
# def is_populated(path):
# def download_and_extract(url, archive, dest, progress=False):
